@@ -1,5 +1,5 @@
 package HTTP::Proxy;
-$HTTP::Proxy::VERSION = '0.303';
+$HTTP::Proxy::VERSION = '0.304';
 use HTTP::Daemon;
 use HTTP::Date qw(time2str);
 use LWP::UserAgent;
@@ -90,6 +90,7 @@ sub new {
         port     => 8080,
         stash    => {},
         timeout  => 60,
+        via      => undef,
         x_forwarded_for => 1,
     );
 
@@ -116,7 +117,10 @@ sub new {
       for keys %defaults;
 
     if (!defined $self->{via}) {
-	$self->{via} = hostname() . ($self->{port} != 80 ? ':' . $self->{port} : '') . " (HTTP::Proxy/$VERSION)";
+        $self->{via} =
+            hostname()
+          . ( $self->{port} != 80 ? ":$self->{port}" : '' )
+          . " (HTTP::Proxy/$VERSION)";
     }
 
     # choose an engine with the remaining parameters
